/*
 * Copyright (C) 2019 - 2025 Devexperts Solutions IE Limited
 * This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
 * If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
 */
import ChartBootstrap from './bootstrap';
import { BarType, PartialChartConfig, YAxisConfigTreasuryFormat } from './chart.config';
import { CandleSeries } from './components/chart/chart.component';
import { PaneComponent, YExtentFormatters } from './components/pane/pane.component';
/**
 * New shiny chart wrapper
 */
export declare class Chart extends ChartBootstrap {
    yAxis: import("./components/y_axis/y-axis.component").YAxisComponent;
    xAxis: import("./components/x_axis/x-axis.component").XAxisComponent;
    watermark: import("./components/watermark/water-mark.component").WaterMarkComponent;
    highlights: import("./components/highlights/highlights.component").HighlightsComponent;
    events: import("./components/events/events.component").EventsComponent;
    snapshot: import("./components/snapshot/snapshot.component").SnapshotComponent;
    crosshair: import("./components/cross_tool/cross-tool.component").CrossToolComponent;
    navigationMap: import("./components/navigation_map/navigation-map.component").NavigationMapComponent;
    volumes: import("./components/volumes/volumes.component").VolumesComponent;
    cursors: import("./canvas/cursor.handler").CursorHandler;
    data: import("./components/chart/chart.component").ChartComponent;
    scale: import("./model/scale.model").ScaleModel;
    panning: import("./components/pan/chart-pan.component").ChartPanComponent;
    bounds: import("./canvas/canvas-bounds-container").CanvasBoundsContainer;
    hover: import("./inputhandlers/hover-producer.component").HoverProducerComponent;
    constructor(element: HTMLElement, config?: PartialChartConfig);
    /**
     * Registers number formatters for pane
     * @param uuid - pane's id
     * @param formatters - object, that contains 3 fileds: 'regular', 'percent', 'logarithmic'.
     * Each filed must have it's own formatter.
     * If 'percent' and 'logarithmic' formatters did not provided, 'regular' will be applied.
     */
    registerPaneFormatters(uuid: string, formatters: YExtentFormatters): void;
    /**
     * Contains tear-down logic for chart
     * Use when you want to unmount the chart from the host app
     */
    destroy(): void;
    /**
     * Sets the visibility of the volumes separately and updates the yAxis width.
     * @param {boolean} separate - A boolean value indicating whether to show the volumes separately or not. Default value is false.
     */
    showSeparateVolumes(separate?: boolean): void;
    setData(data: CandleSeries | CandleSeries[]): void;
    updateData(data: CandleSeries | CandleSeries[]): void;
    /**
     * Sets the auto scale property of the scale model.
     * @param {boolean} auto - A boolean value indicating whether the auto scale is enabled or not. Default value is true.
     */
    setAutoScale(auto?: boolean): void;
    /**
     * Sets the right-to-left (RTL) configuration of the component.
     *
     * @param {boolean} rtl - A boolean value indicating whether the component should be displayed in RTL mode.
     * @returns {void}
     */
    setRtl(rtl: boolean): void;
    setChartType(type: BarType): void;
    /**
     * Sets if regular or logarithmic price types should apply treasury format
     */
    setTreasuryFormat(treasuryFormat: YAxisConfigTreasuryFormat): void;
    createPane(): PaneComponent;
}
