/*
 * Copyright (C) 2019 - 2025 Devexperts Solutions IE Limited
 * This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
 * If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
 */
import { nameDirection } from '../../model/candle.model';
import { VisualSeriesPoint } from '../../model/data-series.model';
import VisualCandle from '../../model/visual-candle';
import { DEFAULT_PERIOD, fakeCandle, fakeDataPoint } from './fake-candles';
/**
 * Generates fake candle for left and right "out of data range" zones.
 * Requires period to calculate the fake timestamp.
 * The timestamp won't take session breaks or holidays into account.
 */
export const fakeVisualCandle = (dataPoints, visualCandles, candleWidth, index, period = DEFAULT_PERIOD) => {
    const candle = fakeCandle(dataPoints, index, period);
    // in case we have equivolume
    candle.volume = candleWidth;
    let x;
    if (visualCandles.length === 0) {
        x = 0;
    }
    else if (index >= visualCandles.length) {
        const lastCandle = visualCandles[visualCandles.length - 1];
        const candlesCountInBetween = index - (visualCandles.length - 1);
        const offsetFromLast = candlesCountInBetween * candleWidth;
        x = lastCandle.centerUnit + offsetFromLast;
    }
    else {
        const firstCandle = visualCandles[0];
        const candlesCountInBetween = -index;
        const offsetFromFirst = candlesCountInBetween * candleWidth;
        x = firstCandle.centerUnit - offsetFromFirst;
    }
    return new VisualCandle(x, candleWidth, candle.open, candle.close, candle.lo, candle.hi, nameDirection(candle.open, candle.close), candle);
};
export const fakeVisualPoint = (dataPoints, visualPoints, meanDataWidth, index, period = DEFAULT_PERIOD) => {
    const candle = fakeDataPoint(dataPoints, index, period);
    let x;
    if (visualPoints.length === 0) {
        x = 0;
    }
    else if (index >= visualPoints.length) {
        const lastCandle = visualPoints[visualPoints.length - 1];
        const candlesCountInBetween = index - (visualPoints.length - 1);
        const offsetFromLast = candlesCountInBetween * meanDataWidth;
        x = lastCandle.centerUnit + offsetFromLast;
    }
    else {
        const firstCandle = visualPoints[0];
        const candlesCountInBetween = -index;
        const offsetFromFirst = candlesCountInBetween * meanDataWidth;
        x = firstCandle.centerUnit - offsetFromFirst;
    }
    return new VisualSeriesPoint(x, candle.close);
};
