/*
 * Copyright (C) 2019 - 2025 Devexperts Solutions IE Limited
 * This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
 * If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
 */
import { unitToPercent } from '../../../model/scaling/viewport.model';
import { PriceIncrementsUtils } from '../../../utils/price-increments.utils';
import { treasuryPriceFormatter } from './treasury-price.formatter';
export const createRegularPriceFormatter = (extent, config) => (value) => {
    let checkedValue;
    if (typeof value === 'number') {
        checkedValue = value;
    }
    else if (typeof value === 'string') {
        checkedValue = Number(value);
    }
    else {
        return '—';
    }
    const treasuryFormatConfig = config.treasuryFormat;
    if (treasuryFormatConfig && treasuryFormatConfig.enabled) {
        return treasuryPriceFormatter(checkedValue);
    }
    const [mainDataSeries] = extent.dataSeries;
    if (mainDataSeries !== undefined) {
        const precision = PriceIncrementsUtils.getPricePrecision(checkedValue, mainDataSeries.pricePrecisions);
        return checkedValue.toFixed(precision);
    }
    return `${checkedValue}`;
};
export const createPercentFormatter = (extent) => (value, dataSeries) => {
    const [mainDataSeries] = extent.dataSeries;
    let valueUnit = value;
    const series = dataSeries !== null && dataSeries !== void 0 ? dataSeries : mainDataSeries;
    if (series !== undefined) {
        valueUnit = unitToPercent(value, series.getBaseline());
    }
    // always apply default precision for percent
    const formatted = valueUnit.toFixed(PriceIncrementsUtils.DEFAULT_PRECISION).replace('-', '−') + ' %';
    return formatted === '−0.00 %' ? '0.00 %' : formatted;
};
export const createYExtentFormatters = (extent, config) => ({
    percent: createPercentFormatter(extent),
    regular: createRegularPriceFormatter(extent, config),
});
