/*
 * Copyright (C) 2019 - 2025 Devexperts Solutions IE Limited
 * This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
 * If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
 */
import { ChartBaseElement } from '../../model/chart-base-element';
import { GridDrawer } from './grid.drawer';
export class GridComponent extends ChartBaseElement {
    constructor(canvasModel, viewportModel, config, yAxisState, drawerName, drawingManager, xBoundsProvider, yBoundsProvider, xLabelsProvider, yLabelsProvider, getBaseline, drawPredicate) {
        super();
        this.drawerName = drawerName;
        this.drawingManager = drawingManager;
        this.drawer = new GridDrawer(canvasModel, viewportModel, config, yAxisState, xBoundsProvider, yBoundsProvider, xLabelsProvider, yLabelsProvider, drawPredicate, getBaseline);
    }
    /**
     * This method is used to deactivate the drawer and remove it from the drawing manager.
     * @protected
     * @function
     * @name doDeactivate
     * @returns {void}
     */
    doDeactivate() {
        super.doDeactivate();
        this.drawingManager.removeDrawer(this.drawer);
    }
    /**
     * This method is used to activate the drawer. It calls the parent class's doActivate method and adds the drawer to the drawing manager.
     * @protected
     * @function
     * @returns {void}
     */
    doActivate() {
        super.doActivate();
        this.drawingManager.addDrawer(this.drawer, this.drawerName);
    }
}
