/*
 * Copyright (C) 2019 - 2025 Devexperts Solutions IE Limited
 * This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
 * If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
 */
import { NumericAxisLabelsGenerator } from '../labels_generator/numeric-axis-labels.generator';
/**
 * Y axis labels generator for prices. Respects price increment from instrument.
 */
export class NumericXAxisLabelsGenerator extends NumericAxisLabelsGenerator {
    constructor(viewportModel, valueFormatter = value => `${value}`) {
        super(null, () => [viewportModel.yStart, viewportModel.yEnd], () => viewportModel.getBounds().width, valueFormatter, false, () => 'regular', () => 0, undefined);
    }
    get labels() {
        return this.labelsCache.calculateOrGet();
    }
    /**
     * Recalculates the labels of the chart.
     * Calls the generateNumericLabels method to generate new numeric labels.
     */
    recalculateLabels() {
        this.generateNumericLabels();
    }
    /**
     * Invalidates the labels cache and generates numeric labels.
     * @returns {void}
     */
    generateLabels() {
        this.labelsCache.invalidate();
        this.generateNumericLabels();
    }
}
